<?php 
namespace App\Http\Controllers;
use App\DataTables\UsersDataTable;
   
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\User;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Validator;
use DB;
use Hash;
use Auth;
use Illuminate\Support\Arr;
use DataTables;

class AdminController extends Controller
{
    public function index()
    {   
        $admins = User::select('*','users.id as uid')->join('model_has_roles','users.id','=','model_has_roles.model_id')->where('model_has_roles.role_id',2)->OrderBy('users.id','DESC')->get();
        return view('pages.admins.index',compact('admins'));
    }

    public function changePas(){
        return view('pages.change-pas');
    }

    public function pasUpdate(Request $request){
        $admin = User::find(Auth::user()->id);  
        $admin->password   = Hash::make($request->password);
        $admin->save();
        return redirect('admins')->with('message', 'Password Updated successfully');
    }

    /**
        * Show the form for creating a new resource.
        *
        * @return Response
    */

    public function create()
    {
        $user_roles = array( '1' => 'Admin Panel', '2' => 'Order Panel', '3' => 'Inventory Panel');
        return view('pages.admins.create',compact('user_roles'));
    }

    /**
        * Store a newly created resource in storage.
        *
        * @return Response
    */
    public function store(Request $request)
    {
       // return $request;
        if(isset($request->mobile)){
            $validator = Validator::make($request->all(), [
                'first_name'       => 'required',
                'email'            => 'required|unique:users',
                'password'         => 'required|min:8',
                'confirm_password' => 'required|same:password',
                'user_role'        => 'required',
                'mobile'           => 'required',
            ]);
        }else{
            $validator = Validator::make($request->all(), [
                'first_name'       => 'required',
                'email'            => 'required|unique:users',
                'password'         => 'required|min:8',
                'confirm_password' => 'required|same:password',
                'user_role'        => 'required',
            ]);
        }
        

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
 

        $admin = new User;
        $admin->first_name = $request->first_name;
        $admin->last_name  = $request->last_name;
        $admin->email      = $request->email;

        if($request->has('mobile')){
         $num = preg_replace('/[0-9]{3}\.?([0-9]{3})\.?([0-9]{4})/', '', $request->mobile);
        $admin->mobile     = $num;    
        }
        
        $admin->password   = Hash::make($request->password);
        if(isset($request->show_price)){
            $admin->show_price = $request->show_price;
        }else{
            $admin->show_price = 0;
        }
        if(!empty($request->user_role)){
            $user_role = implode(",",$request->user_role);
            $admin->user_role = $user_role;
        }

        $admin->save();
        $admin->assignRole( array('0' => 2 ));
        return redirect('admins')->with('message', 'Admin has been created successfully');
    }

    /**
        * Display the specified resource.
        *
        * @param  int  $id
        * @return Response
    */

    public function show($id)
    {
        $admin = User::find($id);
        if(isset($admin->user_role)){
            $role_arr = explode(",",$admin->user_role);
        }else{
            $role_arr = array();
        }
        $user_roles = array( '1' => 'Admin Panel', '2' => 'Order Panel', '3' => 'Inventory Panel');
        return view('pages.admins.show',compact('admin','user_roles','role_arr'));
    }

    /**
        * Show the form for editing the specified resource.
        *
        * @param  int  $id
        * @return Response
    */
    public function edit($id)
    {
        $admin = User::find($id);  
        if(isset($admin->user_role)){
            $role_arr = explode(",",$admin->user_role);
        }else{
            $role_arr = array();
        }
        $user_roles = array( '1' => 'Admin Panel', '2' => 'Order Panel', '3' => 'Inventory Panel');
        return view('pages.admins.edit',compact('admin','user_roles','role_arr','id'));
    }

    /**
        * Update the specified resource in storage.
        *
        * @param  int  $id
        * @return Response
    */

    public function update(Request $request, $id)
    {
        if (isset($request->confirm_password)) {
            if(isset($request->mobile)){
                $validator = Validator::make($request->all(), [
                    'first_name'       => 'required',
                    'email'            => 'required|email|unique:users,email,'.$id,
                    'password'         => 'required|min:8',
                    'confirm_password' => 'required|same:password',
                    'user_role'        => 'required',
                    'mobile'           => 'required',
                ]);
            }else{
                $validator = Validator::make($request->all(), [
                    'first_name'       => 'required',
                    'email'            => 'required|email|unique:users,email,'.$id,
                    'password'         => 'required|min:8',
                    'confirm_password' => 'required|same:password',
                    'user_role'        => 'required',
                ]);
            }    
        }else{
            if(isset($request->mobile)){
                $validator = Validator::make($request->all(), [
                    'first_name'       => 'required',
                    'email'            => 'required|email|unique:users,email,'.$id,
                    'mobile'           => 'required',
                    ]);
                }else{
                $validator = Validator::make($request->all(), [
                    'first_name'       => 'required',
                    'email'            => 'required|email|unique:users,email,'.$id,
                    'user_role'        => 'required',
                ]);
            }
        }

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $admin = User::find($id);
        $admin->first_name = $request->first_name;
        $admin->last_name  = $request->last_name;
        $admin->email      = $request->email;
        
        if($request->has('mobile')){
        $num = preg_replace('/[0-9]{3}\.?([0-9]{3})\.?([0-9]{4})/', '', $request->mobile);
        $admin->mobile     = $num;    
        }
        if(!empty($request->user_role)){
            $user_role = implode(",",$request->user_role);
            $admin->user_role = $user_role;
        }
        if(isset($request->show_price)){
            $admin->show_price = $request->show_price;
        }else{
            $admin->show_price = 0;
        }
        if (isset($request->confirm_password)) {
            $admin->password   = Hash::make($request->password);
        }
        
        $admin->save();
        return redirect('admins')->with('message', 'Admin has been updated successfully');
    }

    /**
        * Remove the specified resource from storage.
        *
        * @param  int  $id
        * @return Response
        */
    public function destroy($id)
    {
        $admin = User::find($id);
        $admin->delete();
        return redirect('admins')->with('message', 'Admin has been deleted successfully');
    }

    public function role($id)
    {
        $admin = User::find($id);   
        if(isset($admin->user_role)){
            $role_arr = explode(",",$admin->user_role);
        }else{
            $role_arr = array();
        }
        $user_roles = array( '1' => 'Admin Panel', '2' => 'Order Panel', '3' => 'Inventory Panel');
        return view('pages.admins.role',compact('admin','user_roles','role_arr','id'));
    }

    public function role_store(Request $request,$id)
    {  
        $admin = User::find($id);
        if(!empty($request->user_role)){
            $user_role = implode(",",$request->user_role);
            $admin->user_role = $user_role;
            $admin->save();
        }
        return redirect('admins')->with('message', 'Admin role has been created successfully');
    }


}