<?php 

namespace App\Http\Controllers;
use App\DataTables\UsersDataTable;
   
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\ProductCategory;
use App\Models\Product;
use App\Models\Foam_Style;
use App\Models\Item;
use App\Models\Foam_Grade;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Validator;
use DB;
use Hash;
use Illuminate\Support\Arr;
use DataTables;
use App\Models\{Country,State,City};

class BedController extends Controller
{
    public function index()
    {   
        $bed = Product::OrderBy('id','DESC')->where('product_cat_id',7)->get();
        return view('pages.products.bed.index',compact('bed'));
    }

    /**
        * Show the form for creating a new resource.
        *
        * @return Response
    */

    public function create()
    {
        $foam_styles = DB::table('item')
            ->select('item.id','products.name')
            ->join('products','products.id','=','item.style')
            ->where(['item.item_cat_id' => '2'])->orderBy('name','ASC')->get();
        $lags        = Item::where('item_cat_id',3)->orderBy('name','ASC')->get();
        $foam_grades = Foam_Grade::orderBy('name','ASC')->get();
        $pillow  = Product::where('product_cat_id',9)->orderBy('name','ASC')->get();
        $nail_heads  = Item::where('item_cat_id',4)->orderBy('name','ASC')->get();
        return view('pages.products.bed.create',compact('foam_styles', 'lags', 'foam_grades', 'nail_heads','pillow'));
    }

    /**
        * Store a newly created resource in storage.
        *
        * @return Response
    */
    public function store(Request $request)
    {
       // return $request;
        $validator = Validator::make($request->all(), [
            'name'             => 'required',
            'fabric_required'  => 'required',
            'foam_count'       => 'required',
            //'foam_style'       => 'required',
            'legs'             => 'required',
            'legs_req'        => 'required|numeric',
            'foam_grade'       => 'required',
            'nail_head'        => 'required',
            //'tufting'          => 'required',
            'image'            => 'required',
        ]);

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $bed = new Product;
        $bed->product_cat_id   = 7;
        $bed->name             = $request->name;
        $bed->fabric_required  = $request->fabric_required;
        $bed->foam_count       = $request->foam_count;
        //$bed->foam_style_id    = $request->foam_style;
        if(isset($request->price)){
            $bed->price        = $request->price;  
        }

        if(!$request->is_pillow_req){
        $bed->pillow_quantity  = $request->pillow_quantity;
        $bed->pillow_product_id  = $request->pillow_product_id;
        $bed->is_pil_not_req    = 0;
        }  else {
        $bed->is_pil_not_req    = 1;
        }

       
        $bed->legs             = $request->legs;
        $bed->legs_req         = $request->legs_req;
        $bed->foam_grade_id    = $request->foam_grade;
        $bed->nail_head        = $request->nail_head;
        $bed->tufting          = $request->tufting;
        $bed->notes            = $request->notes;
        //upload image
        if($request->hasfile('image'))
        {
            $image = $request->file('image');
            $name = time().rand().'.'.$image->getClientOriginalExtension();
            $destinationPath = public_path('/item/fabric/');
            $image->move($destinationPath, $name);
            $bed->image = $name;
        }
        $bed->save();
        return redirect('bed')->with('message', 'Product Bed has been created successfully');
    }

    /**
        * Display the specified resource.
        *
        * @param  int  $id
        * @return Response
    */

    public function show($id)
    {
        $products = Product::find($id);
        return view('pages.products.bed.show',compact('products'));
    }

    /**
        * Show the form for editing the specified resource.
        *
        * @param  int  $id
        * @return Response
    */

    public function edit($id)
    {
        $products    = Product::find($id);
        $foam_styles = DB::table('item')
            ->select('item.id','products.name')
            ->join('products','products.id','=','item.style')
            ->where(['item.item_cat_id' => '2'])->orderBy('id','DESC')->get();
        $lags        = Item::where('item_cat_id',3)->orderBy('id','DESC')->get();
        $foam_grades = Foam_Grade::orderBy('id','DESC')->get();
        $pillow  = Product::where('product_cat_id',9)->get();
        $nail_heads  = Item::where('item_cat_id',4)->orderBy('id','DESC')->get();
        return view('pages.products.bed.edit',compact('products','foam_styles','lags','foam_grades','nail_heads','pillow'));
    }

    /**
        * Update the specified resource in storage.
        *
        * @param  int  $id
        * @return Response
    */

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'name'             => 'required',
            'fabric_required'  => 'required',
            'foam_count'       => 'required',
            //'foam_style'       => 'required',
            //'price'            => 'required',
            'legs_req'        => 'required|numeric',
            'legs'             => 'required',
            'foam_grade'       => 'required',
            'nail_head'        => 'required',
            //'tufting'          => 'required',
        ]);

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $bed = Product::find($id);
        $bed->product_cat_id   = 7;
        $bed->name             = $request->name;
        $bed->fabric_required  = $request->fabric_required;
        $bed->foam_count       = $request->foam_count;
        //$bed->foam_style_id    = $request->foam_style;
        $bed->price            = $request->price;
        $bed->legs             = $request->legs;
        $bed->legs_req         = $request->legs_req;
        //         $bed->pillow_quantity  = $request->pillow_quantity;
        // $bed->pillow_product_id  = $request->pillow_product_id;

        if(!$request->is_pillow_req){
        $bed->pillow_quantity  = $request->pillow_quantity;
        $bed->pillow_product_id  = $request->pillow_product_id;
        $bed->is_pil_not_req    = 0;
        }  else {
        $bed->is_pil_not_req    = 1;
        $bed->pillow_quantity  = 0;
        $bed->pillow_product_id  = 0;
        }
        
        $bed->foam_grade_id    = $request->foam_grade;
        $bed->nail_head        = $request->nail_head;
        $bed->tufting          = $request->tufting;
        $bed->notes            = $request->notes;
        //upload image
        if($request->hasfile('image'))
        {
            $image = $request->file('image');
            $name = time().rand().'.'.$image->getClientOriginalExtension();
            $destinationPath = public_path('/item/fabric/');
            $image->move($destinationPath, $name);
            $bed->image = $name;
        }
        $bed->save();
        return redirect('bed')->with('message', 'Product Bed has been updated successfully');
    }

    /**
        * Remove the specified resource from storage.
        *
        * @param  int  $id
        * @return Response
    */

    public function destroy($id)
    {
        $product = Product::find($id);
        $product->delete();
        return redirect('bed')->with('message', 'Product Bed has been deleted successfully');
    }


}