<?php 
namespace App\Http\Controllers;
use App\DataTables\UsersDataTable;
   
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\User;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Validator;
use DB;
use Hash;
use Illuminate\Support\Arr;
use DataTables;
use App\Models\{Country,State,City};

class CustomerController extends Controller
{
    public function index()
    {   
        $customers = User::join('model_has_roles','users.id','=','model_has_roles.model_id')->where('model_has_roles.role_id',5)->OrderBy('users.id','DESC')->select('*','users.id as uid')->get();
        return view('pages.customers.index',compact('customers'));
    }

    /**
        * Show the form for creating a new resource.
        *
        * @return Response
    */

    public function create()
    {   
        $countries = Country::get(["name","id"]);
        return view('pages.customers.create',compact('countries'));
    }

    /**
        * Store a newly created resource in storage.
        *
        * @return Response
    */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'first_name'       => 'required',
            'email'            => 'required|unique:users',
            'phone'       => 'required',
            'billing_country'       => 'required',
            'billing_provience'       => 'required',
            'billing_pincode'       => 'required',
            //'password'         => 'required|min:8',
            //'confirm_password' => 'required|same:password'
        ]);

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $customer = new User;
        $customer->first_name = $request->first_name;
        $customer->last_name  = $request->last_name;
        $customer->email      = $request->email;
        if($request->has('phone')){
         $num = preg_replace('/[0-9]{3}\.?([0-9]{3})\.?([0-9]{4})/', '', $request->phone);
        $customer->mobile     = $num;    
        }
        $customer->billing_address    = $request->billing_address;
        $customer->billing_city       = $request->billing_city;
        $customer->billing_provience  = $request->billing_provience;
        $customer->billing_country    = $request->billing_country;
        $customer->billing_pincode    = $request->billing_pincode;

        if(isset($customer->update_shipping)){
            $customer->shipping_address   = $request->shipping_address;
            $customer->shipping_city      = $request->shipping_city;
            $customer->shipping_provience = $request->shipping_provience;
            $customer->shipping_country   = $request->shipping_country;
            $customer->shipping_pincode   = $request->shipping_pincode; 
        }else{
            $customer->shipping_address    = $request->billing_address;
            $customer->shipping_city       = $request->billing_city;
            $customer->shipping_provience  = $request->billing_provience;
            $customer->shipping_country    = $request->billing_country;
            $customer->shipping_pincode    = $request->billing_pincode;
        }
        
        $customer->password   = Hash::make(12345678);
        $customer->save();
        $customer->assignRole( array('0' => 5 ));
        return redirect('customers')->with('message', 'Customer has been created successfully');
    }

    /**
        * Display the specified resource.
        *
        * @param  int  $id
        * @return Response
    */

    public function show($id)
    {
        $customer = User::find($id);
        $billing_country   = Country::where("id",$customer->billing_country)->first(["name","id"]);
        $billing_state     = State::where("id",$customer->billing_provience)->first(["name","id"]);
        $billing_city      = City::where("id",$customer->billing_city)->first(["name","id"]);

        $shipping_country   = Country::where("id",$customer->shipping_country)->first(["name","id"]);
        $shipping_state     = State::where("id",$customer->shipping_provience)->first(["name","id"]);
        $shipping_city      = City::where("id",$customer->shipping_city)->first(["name","id"]);
        return view('pages.customers.show',compact('customer','billing_country','billing_state','billing_city','shipping_country','shipping_state','shipping_city'));
    }

    /**
        * Show the form for editing the specified resource.
        *
        * @param  int  $id
        * @return Response
    */
    public function edit($id)
    {
        $customer = User::find($id);
        $countries = Country::get(["name","id"]);
        $billing_states    = State::where("country_id",$customer->billing_country)->get(["name","id"]);
        $billing_cities    = City::where("state_id",$customer->billing_provience)->get(["name","id"]);

        $shipping_states    = State::where("country_id",$customer->shipping_country)->get(["name","id"]);
        $shipping_cities    = City::where("state_id",$customer->shipping_provience)->get(["name","id"]);
        return view('pages.customers.edit',compact('customer','countries','billing_states','billing_cities','shipping_states','shipping_cities'));
    }

    /**
        * Update the specified resource in storage.
        *
        * @param  int  $id
        * @return Response
    */

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'first_name'       => 'required',
            'email'            => 'required|email|unique:users,email,'.$id,
            'phone'       => 'required',
            'billing_country'       => 'required',
            'billing_provience'       => 'required',
            'billing_pincode'       => 'required',
        ]);

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $customer = User::find($id);
        $customer->first_name = $request->first_name;
        $customer->last_name  = $request->last_name;
        $customer->email      = $request->email;
        if($request->has('phone')){
         $num = preg_replace('/[0-9]{3}\.?([0-9]{3})\.?([0-9]{4})/', '', $request->phone);
        $customer->mobile     = $num;    
        }
        $customer->billing_address    = $request->billing_address;
        $customer->billing_city       = $request->billing_city;
        $customer->billing_provience  = $request->billing_provience;
        $customer->billing_country    = $request->billing_country;
        $customer->billing_pincode    = $request->billing_pincode;
        $customer->shipping_address    = $request->billing_address;
        $customer->shipping_city       = $request->billing_city;
        $customer->shipping_provience  = $request->billing_provience;
        $customer->shipping_country    = $request->billing_country;
        $customer->shipping_pincode    = $request->billing_pincode;
        /*if (isset($request->confirm_password)) {
            $customer->password   = Hash::make($request->password);
        }*/
        
        $customer->save();
        return redirect('customers')->with('message', 'Customer has been updated successfully');
    }

    /**
        * Remove the specified resource from storage.
        *
        * @param  int  $id
        * @return Response
        */
    public function destroy($id)
    {
        $customer = User::find($id);
        $customer->delete();
        return redirect('customers')->with('message', 'Customer has been deleted successfully');
    }


}