<?php 
namespace App\Http\Controllers;
use App\DataTables\UsersDataTable;
   
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\User;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Validator;
use DB;
use Hash;
use Illuminate\Support\Arr;
use DataTables;
use App\Models\{Country,State,City};

class DealerController extends Controller
{
    public function index()
    {   
        $dealers = User::join('model_has_roles','users.id','=','model_has_roles.model_id')->where('model_has_roles.role_id',3)->OrderBy('users.id','DESC')->select('*','users.id as uid')->get();
        return view('pages.dealers.index',compact('dealers'));
    }

    /**
        * Show the form for creating a new resource.
        *
        * @return Response
    */

    public function create()
    {
        $countries = Country::get(["name","id"]);
        return view('pages.dealers.create',compact('countries'));
    }

    /**
        * Store a newly created resource in storage.
        *
        * @return Response
    */
    public function store(Request $request)
    {
        if (isset($request->update_shipping)) {
            $validator = Validator::make($request->all(), [
                'first_name'          => 'required',
                'email'               => 'required|unique:users',
                'phone'               => 'required',
                'billing_address'     => 'required',
                'billing_country'     => 'required',
                'billing_provience'   => 'required',
                'billing_city'        => 'required',
                'billing_pincode'     => 'required',
                'shipping_address'    => 'required',
                'shipping_country'    => 'required',
                'shipping_provience'  => 'required',
                'shipping_city'       => 'required',
                'shipping_pincode'    => 'required',
            ]); 
        }else{
            $validator = Validator::make($request->all(), [
                'first_name'          => 'required',
                'email'               => 'required|unique:users',
                'phone'               => 'required',
                'billing_address'     => 'required',
                'billing_country'     => 'required',
                'billing_provience'   => 'required',
                'billing_city'        => 'required',
                'billing_pincode'     => 'required',
            ]);
        }

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $dealer = new User;
        $dealer->first_name = $request->first_name;
        $dealer->last_name  = $request->last_name;
        $dealer->email      = $request->email;

        if($request->has('phone')){
        $num = preg_replace('/[0-9]{3}\.?([0-9]{3})\.?([0-9]{4})/', '', $request->phone);
        $dealer->mobile     = $num;    
        }

        $dealer->billing_address    = $request->billing_address;
        $dealer->billing_city       = $request->billing_city;
        $dealer->billing_provience  = $request->billing_provience;
        $dealer->billing_country    = $request->billing_country;
        $dealer->billing_pincode    = $request->billing_pincode;
        $dealer->shipping_address   = $request->billing_address;
        if(isset($request->update_shipping)){
            $dealer->is_shipping_address_different   = 1;
            $dealer->shipping_address   = $request->shipping_address;
            $dealer->shipping_city      = $request->shipping_city;
            $dealer->shipping_provience = $request->shipping_provience;
            $dealer->shipping_country   = $request->shipping_country;
            $dealer->shipping_pincode   = $request->shipping_pincode; 
        }else{
            $dealer->is_shipping_address_different   = 0;
            $dealer->shipping_city      = $request->billing_city;
            $dealer->shipping_provience = $request->billing_provience;
            $dealer->shipping_country   = $request->billing_country;
            $dealer->shipping_pincode   = $request->billing_pincode; 
        }
        $dealer->password   = Hash::make(12345678);

        if($request->has('password')){
          $dealer->password = Hash::make($request->password);
        }
        
        $dealer->save();
        $dealer->assignRole( array('0' => 3 ));
        return redirect('dealers')->with('message', 'Dealer has been created successfully');
    }

    /**
        * Display the specified resource.
        *
        * @param  int  $id
        * @return Response
    */

    public function show($id)
    {
        $dealer  = User::find($id);
        $billing_country   = Country::where("id",$dealer->billing_country)->first(["name","id"]);
        $billing_state     = State::where("id",$dealer->billing_provience)->first(["name","id"]);
        $billing_city      = City::where("id",$dealer->billing_city)->first(["name","id"]);

        $shipping_country   = Country::where("id",$dealer->shipping_country)->first(["name","id"]);
        $shipping_state     = State::where("id",$dealer->shipping_provience)->first(["name","id"]);
        $shipping_city      = City::where("id",$dealer->shipping_city)->first(["name","id"]);
        return view('pages.dealers.show',compact('dealer','billing_country','billing_state','billing_city','shipping_country','shipping_state','shipping_city'));
    }



    /**
        * Show the form for editing the specified resource.
        *
        * @param  int  $id
        * @return Response
    */
    public function edit($id)
    {
        $dealer = User::find($id);
        $countries = Country::get(["name","id"]);
        $billing_states    = State::where("country_id",$dealer->billing_country)->get(["name","id"]);
        $billing_cities    = City::where("state_id",$dealer->billing_provience)->get(["name","id"]);

        $shipping_states    = State::where("country_id",$dealer->shipping_country)->get(["name","id"]);
        $shipping_cities    = City::where("state_id",$dealer->shipping_provience)->get(["name","id"]);
        return view('pages.dealers.edit',compact('dealer','countries','billing_states','billing_cities','shipping_states','shipping_cities'));
    }

    /**
        * Update the specified resource in storage.
        *
        * @param  int  $id
        * @return Response
    */

    public function update(Request $request, $id)
    {
        if (isset($request->update_shipping)) {
            $validator = Validator::make($request->all(), [
                'first_name'          => 'required',
                'email'               => 'required|email|unique:users,email,'.$id,
                'phone'               => 'required',
                'billing_address'     => 'required',
                'billing_country'     => 'required',
                'billing_provience'   => 'required',
                'billing_city'        => 'required',
                'billing_pincode'     => 'required',
                'shipping_address'    => 'required',
                'shipping_country'    => 'required',
                'shipping_provience'  => 'required',
                'shipping_city'       => 'required',
                'shipping_pincode'    => 'required',
            ]); 
        }else{
            $validator = Validator::make($request->all(), [
                'first_name'          => 'required',
                'email'               => 'required|email|unique:users,email,'.$id,
                'phone'               => 'required',
                'billing_address'     => 'required',
                'billing_country'     => 'required',
                'billing_provience'   => 'required',
                'billing_city'        => 'required',
                'billing_pincode'     => 'required',
            ]);
        }

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $dealer = User::find($id);
        $dealer->first_name = $request->first_name;
        $dealer->last_name  = $request->last_name;
        $dealer->email      = $request->email;
        
        if($request->has('phone')){
         $num = preg_replace('/[0-9]{3}\.?([0-9]{3})\.?([0-9]{4})/', '', $request->phone);
        $dealer->mobile     = $num;    
        }
        $dealer->billing_address    = $request->billing_address;
        $dealer->billing_city       = $request->billing_city;
        $dealer->billing_provience  = $request->billing_provience;
        $dealer->billing_country    = $request->billing_country;
        $dealer->billing_pincode    = $request->billing_pincode;
        if(isset($request->update_shipping)){
            $dealer->is_shipping_address_different   = 1;
            $dealer->shipping_address   = $request->shipping_address;
            $dealer->shipping_city      = $request->shipping_city;
            $dealer->shipping_provience = $request->shipping_provience;
            $dealer->shipping_country   = $request->shipping_country;
            $dealer->shipping_pincode   = $request->shipping_pincode; 
        }else{
            $dealer->is_shipping_address_different   = 0;   
            $dealer->shipping_address   = $request->billing_address;
            $dealer->shipping_city      = $request->billing_city;
            $dealer->shipping_provience = $request->billing_provience;
            $dealer->shipping_country   = $request->billing_country;
            $dealer->shipping_pincode   = $request->billing_pincode; 
        }
        /*if (isset($request->confirm_password)) {
            $dealer->password   = Hash::make($request->password);
        }*/
        
        $dealer->save();
        return redirect('dealers')->with('message', 'Dealer has been updated successfully');
    }

    /**
        * Remove the specified resource from storage.
        *
        * @param  int  $id
        * @return Response
        */
    public function destroy($id)
    {
        $dealer = User::find($id);
        $dealer->delete();
        return redirect('dealers')->with('message', 'Dealer has been deleted successfully');
    }


}