<?php 
namespace App\Http\Controllers;
    
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Item;
use App\Models\Pattern;
use App\Models\Foam_Grade;
use App\Models\Product;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Validator;
use DB;
use Hash;
use Illuminate\Support\Arr;
use Spatie\Permission\Traits\HasRoles;
use Mail;
use DataTables;
use Auth;

class FoamController extends Controller
{
    public function index()
    {   
        $item = Item::where('item_cat_id',2)->orderBy('id','DESC')->get();
        return view('pages.item.foam.index',compact('item'));;
    }

    public function create()
    {
        $foam_grade = Foam_Grade::orderBy('name','ASC')->get(); 
        $patten     = Pattern::orderBy('name','ASC')->get();
        $products   = Product::WhereNotIn('product_cat_id',['9'])->orderBy('name','ASC')->get();
        $suppliers  = User::join('model_has_roles','users.id','=','model_has_roles.model_id')->where('model_has_roles.role_id',4)->OrderBy('users.first_name','ASC')->select('*','users.id as uid')->get();
        return view('pages.item.foam.create',compact('foam_grade','suppliers','patten','products'));
    }

    /**
        * Store a newly created resource in storage.
        *
        * @return Response
    */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'ion_number'          => 'required',
            'is_available'        => 'required',
            'supplier_id'         => 'required',
            'size'                => 'required',
            'style'               => 'required',
        ]);

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
                                                      
        $foam = new Item;
        $foam->ion_number          = $request->ion_number;
        $foam->fabric_grade_id     = $request->fabric_grade_id;
        $foam->notes       = $request->notes;
        if($request->is_available == 'yes'){
            $foam->quantity_available  = $request->quantity_available; 
        }else{
            $foam->quantity_available  = "";
        }
        $foam->is_available = $request->is_available;
        $foam->supplier_id  = $request->supplier_id;
        $foam->style        = $request->style;
        $foam->size         = $request->size;
        $foam->item_cat_id  = 2;
        $foam->save();

        return redirect('foam')->with('message', 'Foam created successfully');
    }

    /**
        * Display the specified resource.
        *
        * @param  int  $id
        * @return Response
    */

    public function show($id)
    {
        $item       = Item::find($id);
        $fab_grade  = Foam_Grade::find($item->fabric_grade_id);
        $supplier   = User::find($item->supplier_id);
        $products   = Product::OrderBy('id','DESC')->WhereNotIn('product_cat_id',['9'])->get();
        return view('pages.item.foam.show',compact( 'item','fab_grade','supplier','products' ));
    }

    /**
        * Show the form for editing the specified resource.
        *
        * @param  int  $id
        * @return Response
    */
    public function edit($id)
    {
        $dealer     = Item::find($id);
        $foam_grade = Foam_Grade::orderBy('name','ASC')->get(); 
        $patten     = Pattern::orderBy('name','ASC')->get(); 
         $suppliers = User::join('model_has_roles','users.id','=','model_has_roles.model_id')->where('model_has_roles.role_id',4)->OrderBy('users.first_name','ASC')->select('*','users.id as uid')->get();
         $products   = Product::WhereNotIn('product_cat_id',['9'])->orderBy('name','ASC')->get();
        return view('pages.item.foam.edit',compact('dealer','foam_grade','suppliers','patten','products'));
    }

    /**
        * Update the specified resource in storage.
        *
        * @param  int  $id
        * @return Response
    */

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'ion_number'            => 'required',
           // 'fabric_grade_id'       => 'required',
            'is_available'            => 'required',
            'supplier_id'       => 'required',
            //'notes'            => 'required',
            'size'       => 'required',
            'style'            => 'required',
        ]);
        

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $foam = Item::find($id);
        $foam->ion_number       = $request->ion_number;
        $foam->fabric_grade_id  = $request->fabric_grade_id;
        $foam->notes            = $request->notes;
        if($request->is_available == 'yes'){
            $foam->quantity_available  = $request->quantity_available; 
        }else{
            $foam->quantity_available  = "";
        }
        $foam->is_available  = $request->is_available;
        $foam->supplier_id   = $request->supplier_id;
        $foam->style         = $request->style;
        $foam->size          = $request->size;
        $foam->save();
        return redirect('foam')->with('message', 'Foam updated successfully');
    }

    /**
        * Remove the specified resource from storage.
        *
        * @param  int  $id
        * @return Response
        */
    public function destroy($id)
    {
        $foam = Item::find($id);
        $foam->delete();
        return redirect('foam')->with('message', 'Foam deleted successfully');
    }



}