<?php 
namespace App\Http\Controllers;
    
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Item;
use App\Models\Foam_Grade;
use App\Models\Fabric;
use App\Models\Wash_Code;
use App\Models\Pattern;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Validator;
use DB;
use Hash;
use Illuminate\Support\Arr;
use Spatie\Permission\Traits\HasRoles;
use Mail;
use DataTables;
use Auth;

class ItemController extends Controller
{
    public function index()
    {   
    	$fabrics = Item::where('item_cat_id',1)->orderBy('id','DESC')->leftjoin('wash_code','wash_code.id','=','item.wash_code_id')->leftjoin('patten','patten.id','=','item.patten_id')->select('item.name','item.id','item.quantity_available','item.ion_number','wash_code.name as washcode','patten.name as pattern_name','item.supplier_id','item.fabric_content','item.fabric_grade_id','item.width','item.rub_count','item.eta_next_arrival_date','item.eta_yards_coming','item.notes','item.image')->get();
       return view('pages.item.fabric.index',compact('fabrics'));;
    }

    public function create()
    {
        $fab_grade = Fabric::orderBy('name', 'ASC')->get();
        $patten    = Pattern::orderBy('name', 'ASC')->get();
        $wash_codes = Wash_Code::orderBy('name', 'ASC')->get();
        $suppliers = User::join('model_has_roles','users.id','=','model_has_roles.model_id')->where('model_has_roles.role_id',4)->select('*','users.id as uid')->orderBy('users.first_name','ASC')->get();

        // return $suppliers;
        return view('pages.item.fabric.create',compact('fab_grade','suppliers','patten','wash_codes'));
    }

    /**
        * Store a newly created resource in storage.
        *
        * @return Response
    */

    public function import_csv()
    {   
       return view('pages.item.fabric.import-csv');;
    }

    public function importFabric(Request $request)
    {   
        $validator = Validator::make($request->all(), [
            'csv_file' => 'required',
        ]);

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
        $file = $request->file('csv_file');

      // File Details 
      $filename = time().rand().'.'.$file->getClientOriginalExtension(); 
      $extension = $file->getClientOriginalExtension();
      $tempPath = $file->getRealPath();
      $fileSize = $file->getSize();
      $mimeType = $file->getMimeType();

      // Valid File Extensions
      $valid_extension = array("csv");

      // 2MB in Bytes
      $maxFileSize = 2097152; 

      // Check file extension
      if(in_array(strtolower($extension),$valid_extension)){

        // Check file size
        if($fileSize <= $maxFileSize){

          // File upload location
          //$location = 'uploads';
          $location = public_path('/item/uploads');

          // Upload file
          $file->move($location,$filename);

          // Import CSV to Database
          $filepath = public_path('/item/uploads'."/".$filename);

          // Reading file
          $file = fopen($filepath,"r");

          $importData_arr = array();
          $i = 0;

          while (($filedata = fgetcsv($file, 1000, ",")) !== FALSE) {
             $num = count($filedata );
             
             // Skip first row (Remove below comment if you want to skip the first row)
             /*if($i == 0){
                $i++;
                continue; 
             }*/
             for ($c=0; $c < $num; $c++) {
                $importData_arr[$i][] = $filedata [$c];
             }
             $i++;
          }
          fclose($file);
          // Insert to MySQL database
          foreach($importData_arr as $key => $importData){

            if($key == 0){
            }else{
                if($importData[15] !=''){
                   $content = file_get_contents($importData[15]);
                    $name    = time().rand();
                    $destinationPath = public_path('/item/fabric/');
                    file_put_contents($destinationPath.$name.".jpg", $content);
                    $image_name = $name.".jpg"; 
                }else{
                    $image_name = "";
                }
                

            if($importData[9] == 2){
                if(isset($importData[13])){
                   $eta_next_arrival_date  = date("Y-m-d", strtotime($importData[13])); 
               }else{
                   $eta_next_arrival_date  = "";
               }
                $eta_yards_coming       = $importData[14];
            }else{
                $eta_next_arrival_date  = "";
                $eta_yards_coming       = "";
            }
           

            $insertData = array(
               "name"=>             $importData[0],
               "ion_number"=>       $importData[1],
               "fabric_grade_id"=>  $importData[2],
               "fabric_content"=>   $importData[3],
               "color"=>            $importData[4],
               "patten_id"=>        $importData[5],
               "width"=>            $importData[6],
               "rub_count"=>        $importData[7],
               "wash_code_id"=>     $importData[8],
               "is_available"=>     $importData[9],
               "supplier_id"=>      $importData[10],
               "quantity_available"=>  $importData[11],               
               "notes"=>            $importData[12],
               "item_cat_id" =>     1,
               'image'      => $image_name,
               "eta_next_arrival_date"=>  $eta_next_arrival_date,               
               "eta_yards_coming"=>        $eta_yards_coming);
               

            Item::insert($insertData);

          }
          }
          return redirect('items')->with('message', 'Fabric Imported successfully');
        }else{
          return redirect('items/create')->with('message', 'File too large. File must be less than 2MB.');
        }

      }else{
         return redirect('items/create')->with('message', 'Invalid File Extension');
      }

    }


    public function store(Request $request)
    {
        if($request->is_available == 2){
            $validator = Validator::make($request->all(), [
                'name'               => 'required',
                'ion_number'         => 'required',
                'fabric_grade_id'    => 'required',
                'fabric_content'     => 'required',
                'color'              => 'required',
                'width'              => 'required',
                'rub_count'          => 'required',
                'wash_code_id'       => 'required',
                'is_available'       => 'required',
                'supplier_id'        => 'required',
                //'quantity_available' => 'required',
                //'notes'              => 'required',
                'image'              => 'required',
                'eta_next_arrival_date'  => 'required',
                'eta_yards_coming'       => 'required',
                'patten_id'            => 'required',
            ]);
        }else{
            $validator = Validator::make($request->all(), [
                'name'               => 'required',
                'ion_number'         => 'required',
                'fabric_grade_id'    => 'required',
                'fabric_content'     => 'required',
                'color'              => 'required',
                'width'              => 'required',
                'rub_count'          => 'required',
                'wash_code_id'       => 'required',
                'is_available'       => 'required',
                'supplier_id'        => 'required',
                //'quantity_available' => 'required',
                //'notes'              => 'required',
                'image'              => 'required',
                'patten_id'            => 'required',
            ]);
        }

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }
                                                      
        $fabric = new Item;
        $fabric->name             = $request->name;
        $fabric->ion_number       = $request->ion_number;
        $fabric->item_cat_id      = 1;
        $fabric->fabric_grade_id  = $request->fabric_grade_id;
        $fabric->fabric_content   = $request->fabric_content;
        $fabric->color            = $request->color;
        $fabric->width            = $request->width;
        $fabric->rub_count        = $request->rub_count;
        $fabric->wash_code_id     = $request->wash_code_id;
        $fabric->supplier_id      = $request->supplier_id;
        $fabric->patten_id        = $request->patten_id;
        $fabric->is_available     = $request->is_available;
        $fabric->notes            = $request->notes;
        if($request->is_available == 1){}else{
            $fabric->quantity_available  = $request->quantity_available;
        }

        if($request->is_available == 2){
            $fabric->eta_next_arrival_date  = date("Y-m-d", strtotime($request->eta_next_arrival_date));
            $fabric->eta_yards_coming  = $request->eta_yards_coming;
        }

        //upload image
        if($request->hasfile('image'))
        {
            $image = $request->file('image');
            $name  = time().rand().'.'.$image->getClientOriginalExtension();
            $destinationPath = public_path('/item/fabric/');
            $image->move($destinationPath, $name);
            $fabric->image   = $name;
        }
        $fabric->save();
        return redirect('items')->with('message', 'Fabric created successfully');
    }

    /**
        * Display the specified resource.
        *
        * @param  int  $id
        * @return Response
    */

    public function show($id)
    {
        $item           = Item::find($id);
        $fab_grade      = Fabric::find($item->fabric_grade_id);
        $patten         = Pattern::find($item->patten_id);
        $wash_code      = Wash_Code::find($item->wash_code_id);
        $supplier       = User::find($item->supplier_id);
        return view('pages.item.fabric.show',compact('item','fab_grade','supplier','patten','wash_code'));
    }

    /**
        * Show the form for editing the specified resource.
        *
        * @param  int  $id
        * @return Response
    */
    public function edit($id)
    {
        $patten = Pattern::orderBy('name', 'ASC')->get();
        $dealer = Item::find($id);
        $fab_grade = Fabric::orderBy('name', 'ASC')->get();
        $wash_codes = Wash_Code::orderBy('name', 'ASC')->get();
        $suppliers = User::join('model_has_roles','users.id','=','model_has_roles.model_id')->where('model_has_roles.role_id',4)->select('*','users.id as uid')->orderBy('users.first_name','ASC')->get();
        return view('pages.item.fabric.edit',compact('dealer','fab_grade','suppliers','patten','wash_codes'));
    }

    /**
        * Update the specified resource in storage.
        *
        * @param  int  $id
        * @return Response
    */

    public function update(Request $request, $id)
    {
       
        if($request->is_available == 2){
            $validator = Validator::make($request->all(), [
                'name'       => 'required',
                'ion_number'            => 'required',
                'fabric_grade_id'            => 'required',
                'fabric_content'            => 'required',
                'color'            => 'required',
                'width'            => 'required',
                'rub_count'            => 'required',
                'wash_code_id'            => 'required',
                'is_available'            => 'required',
                'supplier_id'            => 'required',
                //'quantity_available'            => 'required',
                //'notes'            => 'required',
                'patten_id'            => 'required',
                'eta_next_arrival_date'  => 'required',
                'eta_yards_coming'       => 'required',
                'patten_id'            => 'required',
            ]);
        }else{
            $validator = Validator::make($request->all(), [
                'name'               => 'required',
                'ion_number'         => 'required',
                'fabric_grade_id'    => 'required',
                'fabric_content'     => 'required',
                'color'              => 'required',
                'width'              => 'required',
                'rub_count'          => 'required',
                'wash_code_id'       => 'required',
                'is_available'       => 'required',
                'supplier_id'        => 'required',
                //'quantity_available' => 'required',
                //'notes'              => 'required',
                'patten_id'            => 'required',
            ]);
        }
        

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $fabric = Item::find($id);
        $fabric->name = $request->name;
        $fabric->ion_number  = $request->ion_number;
        $fabric->item_cat_id  = 1;
        $fabric->fabric_grade_id  = $request->fabric_grade_id;
        $fabric->fabric_content  = $request->fabric_content;
        $fabric->color  = $request->color;
        $fabric->width  = $request->width;
        $fabric->rub_count  = $request->rub_count;
        $fabric->wash_code_id  = $request->wash_code_id;
        $fabric->supplier_id  = $request->supplier_id;
        $fabric->is_available  = $request->is_available;
        $fabric->notes  = $request->notes;
        $fabric->patten_id      = $request->patten_id;
        if($request->is_available == 1){
            $fabric->quantity_available = 0;
            if($request->sendmail == 1){
              $mailchc = $this->dealermail($id);
              echo $mailchc;  
            }
          
        }else{
            $fabric->quantity_available  = $request->quantity_available;
        }

        if($request->is_available == 2){
            $fabric->eta_next_arrival_date  = date("Y-m-d", strtotime($request->eta_next_arrival_date));
            $fabric->eta_yards_coming  = $request->eta_yards_coming;
        }

        //upload image
        if($request->hasfile('image'))
        {
            $image = $request->file('image');
            $name = time().rand().'.'.$image->getClientOriginalExtension();
            $destinationPath = public_path('/item/fabric/');
            $image->move($destinationPath, $name);
            $fabric->image = $name;
        }
        $fabric->save();
        return redirect('items')->with('message', 'Fabric updated successfully');
    }

        public function dealermail($id)
    {
        $fabric = Item::where('item.id',$id)->join('fabric_grade','fabric_grade.id','=','item.fabric_grade_id')->join('patten','patten.id','=','item.patten_id')->select('item.*','fabric_grade.name as grade_name','patten.name as pat_name','item.name as item_name')->first();

        $dealers=  User::select('*','users.id as uid')->join('model_has_roles','users.id','=','model_has_roles.model_id')->where('model_has_roles.role_id',3)->OrderBy('users.id','DESC')->get();
        foreach($dealers as $deal){
            $dealer_mail[] = $deal->email;
            $first_name[] = $deal->first_name;

        }


        $data = array( 'first_name'=>$first_name,'fabric_name'=>$fabric->item_name,'fabric'=>$fabric,'name'=>$deal->first_name,'user'=>$deal,'deal_mail'=>$dealer_mail);

        //return $data;
        try{
         Mail::send('email.discontinue', $data, function($message) use($data) {
           // $message->to($data['deal_mail'],$data['name'])

             $message->to("noreply@elitesofas.com");
             foreach ($data['deal_mail'] as $key=> $email) {

                // echo $data['first_name'][$key];
                // return "--";
                    $message->bcc($email,$data['first_name'][$key]);
                //$message->to('pardeep.cracode@gmail.com',$data['first_name'][$key]);
                }

             // $message->to($data['deal_mail'], 'Dealer')
                    $message->subject(' Fabric '.$data['fabric_name'].' has been discontinued.');
            $message->from('team@elitesofa.com','Elite Sofa Team');
        });
     }  catch (\Exception $e) {

    return $e->getMessage();
}
       

    }

    /**
        * Remove the specified resource from storage.
        *
        * @param  int  $id
        * @return Response
        */
    public function destroy($id)
    {
        $dealer = Item::find($id);
        $dealer->delete();
        return redirect('items')->with('message', 'Fabric deleted successfully');
    }



}