<?php 

namespace App\Http\Controllers;
use App\DataTables\UsersDataTable;
   
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\ProductCategory;
use App\Models\Product;
use App\Models\Foam_Style;
use App\Models\Item;
use App\Models\Foam_Grade;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Validator;
use DB;
use Hash;
use Illuminate\Support\Arr;
use DataTables;
use App\Models\{Country,State,City};

class OttomanController extends Controller
{
    public function index()
    {   
        $ottoman = Product::OrderBy('id','DESC')->where('product_cat_id',4)->get();
        return view('pages.products.ottoman.index',compact('ottoman'));
    }

    /**
        * Show the form for creating a new resource.
        *
        * @return Response
    */

    public function create()
    {
        $foam_styles = DB::table('item')
            ->select('item.id','products.name')
            ->join('products','products.id','=','item.style')
            ->where(['item.item_cat_id' => '2'])->orderBy('name','ASC')->get();
        $lags        = Item::where('item_cat_id',3)->orderBy('name','ASC')->get();
        $foam_grades = Foam_Grade::orderBy('name','ASC')->get();
        $nail_heads  = Item::where('item_cat_id',4)->orderBy('name','ASC')->get();
        return view('pages.products.ottoman.create',compact('foam_styles', 'lags', 'foam_grades', 'nail_heads'));
    }

    /**
        * Store a newly created resource in storage.
        *
        * @return Response
    */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name'             => 'required',
            'fabric_required'  => 'required',
            'foam_count'       => 'required',
            //'foam_style'       => 'required',
            'legs'             => 'required',
            'legs_req'        => 'required|numeric',
            'foam_grade'       => 'required',
            'nail_head'        => 'required',
            //'tufting'          => 'required',
            'image'            => 'required',
        ]);

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $ottoman = new Product;
        $ottoman->product_cat_id   = 4;
        $ottoman->name             = $request->name;
        $ottoman->fabric_required  = $request->fabric_required;
        $ottoman->foam_count       = $request->foam_count;
        //$ottoman->foam_style_id    = $request->foam_style;
        if(isset($request->price)){
            $ottoman->price        = $request->price;  
        }
        $ottoman->legs             = $request->legs;
        $ottoman->legs_req         = $request->legs_req;
        $ottoman->foam_grade_id    = $request->foam_grade;
        $ottoman->nail_head        = $request->nail_head;
        $ottoman->tufting          = $request->tufting;
        $ottoman->notes            = $request->notes;
        //upload image
        if($request->hasfile('image'))
        {
            $image = $request->file('image');
            $name = time().rand().'.'.$image->getClientOriginalExtension();
            $destinationPath = public_path('/item/fabric/');
            $image->move($destinationPath, $name);
            $ottoman->image = $name;
        }
        $ottoman->save();
        return redirect('ottoman')->with('message', 'Product Ottoman has been created successfully');
    }

    /**
        * Display the specified resource.
        *
        * @param  int  $id
        * @return Response
    */

    public function show($id)
    {
        $products = Product::find($id);
        return view('pages.products.ottoman.show',compact('products'));
    }

    /**
        * Show the form for editing the specified resource.
        *
        * @param  int  $id
        * @return Response
    */

    public function edit($id)
    {
        $products    = Product::find($id);
        $foam_styles = DB::table('item')
            ->select('item.id','products.name')
            ->join('products','products.id','=','item.style')
            ->where(['item.item_cat_id' => '2'])->orderBy('name','ASC')->get();
        $lags        = Item::where('item_cat_id',3)->orderBy('name','ASC')->get();
        $foam_grades = Foam_Grade::orderBy('name','ASC')->get();
        $nail_heads  = Item::where('item_cat_id',4)->orderBy('name','ASC')->get();
        return view('pages.products.ottoman.edit',compact('products','foam_styles','lags','foam_grades','nail_heads'));
    }

    /**
        * Update the specified resource in storage.
        *
        * @param  int  $id
        * @return Response
    */

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'name'             => 'required',
            'fabric_required'  => 'required',
            'foam_count'       => 'required',
            //'foam_style'       => 'required',
            //'price'            => 'required',
            'legs'             => 'required',
            'legs_req'        => 'required|numeric',
            'foam_grade'       => 'required',
            'nail_head'        => 'required',
            //'tufting'          => 'required',
        ]);

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $ottoman = Product::find($id);
        $ottoman->product_cat_id   = 4;
        $ottoman->name             = $request->name;
        $ottoman->fabric_required  = $request->fabric_required;
        $ottoman->foam_count       = $request->foam_count;
        //$ottoman->foam_style_id    = $request->foam_style;
        $ottoman->price            = $request->price;
        $ottoman->legs             = $request->legs;
        $ottoman->legs_req         = $request->legs_req;
        $ottoman->foam_grade_id    = $request->foam_grade;
        $ottoman->nail_head        = $request->nail_head;
        $ottoman->tufting          = $request->tufting;
        $ottoman->notes            = $request->notes;
        //upload image
        if($request->hasfile('image'))
        {
            $image = $request->file('image');
            $name = time().rand().'.'.$image->getClientOriginalExtension();
            $destinationPath = public_path('/item/fabric/');
            $image->move($destinationPath, $name);
            $ottoman->image = $name;
        }
        $ottoman->save();
        return redirect('ottoman')->with('message', 'Product Ottoman has been updated successfully');
    }

    /**
        * Remove the specified resource from storage.
        *
        * @param  int  $id
        * @return Response
    */

    public function destroy($id)
    {
        $product = Product::find($id);
        $product->delete();
        return redirect('ottoman')->with('message', 'Product Ottoman has been deleted successfully');
    }


}