<?php 
namespace App\Http\Controllers;
use App\DataTables\UsersDataTable;
   
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\User;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Validator;
use DB;
use Hash;
use Illuminate\Support\Arr;
use DataTables;
use App\Models\{Country,State,City};

class SupplierController extends Controller
{
    public function index()
    {   
        $suppliers = User::join('model_has_roles','users.id','=','model_has_roles.model_id')->where('model_has_roles.role_id',4)->OrderBy('users.id','DESC')->select('*','users.id as uid')->get();
        return view('pages.suppliers.index',compact('suppliers'));
    }

    /**
        * Show the form for creating a new resource.
        *
        * @return Response
    */

    public function create()
    {
        $countries = Country::get(["name","id"]);
        return view('pages.suppliers.create',compact('countries'));
    }

    /**
        * Store a newly created resource in storage.
        *
        * @return Response
    */
    public function store(Request $request)
    {
        if (isset($request->update_shipping)) {
            $validator = Validator::make($request->all(), [
                'first_name'          => 'required',
                'email'               => 'required|unique:users',
                'phone'               => 'required',
                'billing_address'     => 'required',
                'billing_country'     => 'required',
                'billing_provience'   => 'required',
                'billing_city'        => 'required',
                'billing_pincode'     => 'required',
                'shipping_address'    => 'required',
                'shipping_country'    => 'required',
                'shipping_provience'  => 'required',
                'shipping_city'       => 'required',
                'shipping_pincode'    => 'required',
            ]); 
        }else{
            $validator = Validator::make($request->all(), [
                'first_name'          => 'required',
                'email'               => 'required|unique:users',
                'phone'               => 'required',
                'billing_address'     => 'required',
                'billing_country'     => 'required',
                'billing_provience'   => 'required',
                'billing_city'        => 'required',
                'billing_pincode'     => 'required',
            ]);
        }

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $supplier = new User;
        $supplier->first_name = $request->first_name;
        $supplier->last_name  = $request->last_name;
        $supplier->email      = $request->email;
        if($request->has('phone')){
        $num = preg_replace('/[0-9]{3}\.?([0-9]{3})\.?([0-9]{4})/', '', $request->phone);
        $supplier->mobile     = $num;    
        }
        $supplier->billing_address    = $request->billing_address;
        $supplier->billing_city       = $request->billing_city;
        $supplier->billing_provience  = $request->billing_provience;
        $supplier->billing_country    = $request->billing_country;
        $supplier->billing_pincode    = $request->billing_pincode;

        if(isset($request->update_shipping)){
            $supplier->is_shipping_address_different   = 1;
            $supplier->shipping_address   = $request->shipping_address;
            $supplier->shipping_city      = $request->shipping_city;
            $supplier->shipping_provience = $request->shipping_provience;
            $supplier->shipping_country   = $request->shipping_country;
            $supplier->shipping_pincode   = $request->shipping_pincode; 
        }else{
            $supplier->is_shipping_address_different   = 0;
            $supplier->shipping_address   = $request->billing_address;
            $supplier->shipping_city      = $request->billing_city;
            $supplier->shipping_provience = $request->billing_provience;
            $supplier->shipping_country   = $request->billing_country;
            $supplier->shipping_pincode   = $request->billing_pincode; 
        }
        $supplier->password   = Hash::make(12345678);
        $supplier->save();
        $supplier->assignRole( array('0' => 4 ));
        return redirect('suppliers')->with('message', 'Supplier has been created successfully');
    }

    /**
        * Display the specified resource.
        *
        * @param  int  $id
        * @return Response
    */

    public function show($id)
    {
        $supplier  = User::find($id);

        $billing_country   = Country::where("id",$supplier->billing_country)->first(["name","id"]);
        $billing_state     = State::where("id",$supplier->billing_provience)->first(["name","id"]);
        $billing_city      = City::where("id",$supplier->billing_city)->first(["name","id"]);

        $shipping_country   = Country::where("id",$supplier->shipping_country)->first(["name","id"]);
        $shipping_state     = State::where("id",$supplier->shipping_provience)->first(["name","id"]);
        $shipping_city      = City::where("id",$supplier->shipping_city)->first(["name","id"]);
        return view('pages.suppliers.show',compact('supplier','billing_country','billing_state','billing_city','shipping_country','shipping_state','shipping_city'));
    }

    /**
        * Show the form for editing the specified resource.
        *
        * @param  int  $id
        * @return Response
    */
    public function edit($id)
    {
        $supplier  = User::find($id);
        $countries = Country::get(["name","id"]);
        $billing_states    = State::where("country_id",$supplier->billing_country)->get(["name","id"]);
        $billing_cities    = City::where("state_id",$supplier->billing_provience)->get(["name","id"]);

        $shipping_states    = State::where("country_id",$supplier->shipping_country)->get(["name","id"]);
        $shipping_cities    = City::where("state_id",$supplier->shipping_provience)->get(["name","id"]);
        return view('pages.suppliers.edit',compact('supplier','countries','billing_states','billing_cities','shipping_states','shipping_cities'));
    }

    /**
        * Update the specified resource in storage.
        *
        * @param  int  $id  
        * @return Response
    */ 

    public function update(Request $request, $id)
    { 
        //return $request;
        //die;
        if (isset($request->update_shipping)) {
            $validator = Validator::make($request->all(), [
                'first_name'          => 'required',
                'email'               => 'required|email|unique:users,email,'.$id,
                'phone'               => 'required',
                'billing_address'     => 'required',
                'billing_country'     => 'required',
                'billing_provience'   => 'required',
                'billing_city'        => 'required',
                'billing_pincode'     => 'required',
                'shipping_address'    => 'required',
                'shipping_country'    => 'required',
                'shipping_provience'  => 'required',
                'shipping_city'       => 'required',
                'shipping_pincode'    => 'required',
            ]); 
        }else{
            $validator = Validator::make($request->all(), [
                'first_name'          => 'required',
                'email'               => 'required|email|unique:users,email,'.$id,
                'phone'               => 'required',
                'billing_address'     => 'required',
                'billing_country'     => 'required',
                'billing_provience'   => 'required',
                'billing_city'        => 'required',
                'billing_pincode'     => 'required',
            ]);
        }

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }

        $supplier = User::find($id);
        $supplier->first_name  = $request->first_name;
        $supplier->last_name   = $request->last_name;
        $supplier->email       = $request->email;
        if($request->has('phone')){
        //$num = preg_replace('/[^0-9.]/', '', $request->phone);
        $num = preg_replace('/[0-9]{3}\.?([0-9]{3})\.?([0-9]{4})/', '', $request->phone);
        $supplier->mobile     = $num;    
        }
        $supplier->billing_address    = $request->billing_address;
        $supplier->billing_city       = $request->billing_city;
        $supplier->billing_provience  = $request->billing_provience;
        $supplier->billing_country    = $request->billing_country;
        $supplier->billing_pincode    = $request->billing_pincode;
        if(isset($request->update_shipping)){
            $supplier->is_shipping_address_different   = 1;
            $supplier->shipping_address   = $request->shipping_address;
            $supplier->shipping_city      = $request->shipping_city;
            $supplier->shipping_provience = $request->shipping_provience;
            $supplier->shipping_country   = $request->shipping_country;
            $supplier->shipping_pincode   = $request->shipping_pincode; 
        }else{
            $supplier->is_shipping_address_different   = 0;
            $supplier->shipping_address   = $request->billing_address;
            $supplier->shipping_city      = $request->billing_city;
            $supplier->shipping_provience = $request->billing_provience;
            $supplier->shipping_country   = $request->billing_country;
            $supplier->shipping_pincode   = $request->billing_pincode; 
        }
        /*if (isset($supplier->confirm_password)) {
            $supplier->password   = Hash::make($request->password);
        }*/
        
        $supplier->save();
        return redirect('suppliers')->with('message', 'Supplier has been updated successfully');
    }

    /**
        * Remove the specified resource from storage.
        *
        * @param  int  $id
        * @return Response
        */
    public function destroy($id)
    {
        $supplier = User::find($id);
        $supplier->delete();
        return redirect('suppliers')->with('message', 'Supplier has been deleted successfully');
    }


}