<?php

namespace App\Http\Controllers;
use App\DataTables\UsersDataTable;
   
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\Country;
use Spatie\Permission\Models\Role;
use DB;
use Hash;
use Auth;
use Illuminate\Support\Arr;
use DataTables;
use Validator;

    
class UserController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {  
        $users = User::OrderBy('id','DESC')->get();
        return view('pages.users.index',compact('users'));
    }

    public function getUsers(Request $request)
    {  
         
             if ($request->ajax()) {
        $data = User::all()->all();
        return Datatables::of($data)
            ->addIndexColumn()
            ->addColumn('action', function($row){

                $btn = '<a href="javascript:void(0)" class="edit btn btn-primary btn-sm">View</a>';

                return $btn;
            })
            ->rawColumns(['action'])
            ->make(true);
    }
}
    

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $roles = Role::pluck('name','name')->all();
        
        return view('pages.users.create',compact('roles'));
    }

        public function get_profile()
    {
        $user = User::where('id',Auth::user()->id)->first();
          $countries = Country::get(["name","id"]);
        
        return view('pages.users.profile',compact('user','countries'));
    }
    
    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'first_name' => 'required',
            'email' => 'required|email|unique:users,email',
            'password' => 'required|same:confirm-password',
            //'roles' => 'required'
        ]);
    
        $input = $request->all();
        $input['password'] = Hash::make($input['password']);
    
        $user = User::create($input);
        //$user->assignRole($request->input('roles'));
        $user->assignRole( array('0' => 2 ));
    
        return redirect()->route('users.index')
                        ->with('success','User created successfully');
    }
    
    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $user = User::find($id);
        //return view('users.show',compact('user'));
    }
    
    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $user = User::find($id);
        $roles = Role::pluck('name','name')->all();
        $userRole = $user->roles->pluck('name','name')->all();
    
        return view('users.edit',compact('user','roles','userRole'));
    }
    
    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|email|unique:users,email,'.$id,
            'password' => 'same:confirm-password',
            'roles' => 'required'
        ]);
    
        $input = $request->all();
        if(!empty($input['password'])){ 
            $input['password'] = Hash::make($input['password']);
        }else{
            $input = Arr::except($input,array('password'));    
        }
    
        $user = User::find($id);
        $user->update($input);
        DB::table('model_has_roles')->where('model_id',$id)->delete();
    
        $user->assignRole($request->input('roles'));
    
        return redirect()->route('users.index')
                        ->with('success','User updated successfully');
    }

        public function update_profile(Request $request)
    {
        $id = Auth::user()->id;
        if (isset($request->update_shipping)) {
            $validator = Validator::make($request->all(), [
                'first_name'          => 'required',
                'email'               => 'required|email|unique:users,email,'.$id,
                'phone'               => 'required',
                'billing_address'     => 'required',
                'billing_country'     => 'required',
                'billing_provience'   => 'required',
                'billing_city'        => 'required',
                'billing_pincode'     => 'required',
                'shipping_address'    => 'required',
                'shipping_country'    => 'required',
                'shipping_provience'  => 'required',
                'shipping_city'       => 'required',
                'shipping_pincode'    => 'required',
            ]); 
        }else{
            $validator = Validator::make($request->all(), [
                'first_name'          => 'required',
                'email'               => 'required|email|unique:users,email,'.$id,
                'phone'               => 'required',
                'billing_address'     => 'required',
                'billing_country'     => 'required',
                'billing_provience'   => 'required',
                'billing_city'        => 'required',
                'billing_pincode'     => 'required',
            ]);
        }

        if ($validator->fails()){
            return redirect()->back()->withErrors($validator)->withInput();
        }


        $supplier = User::find($id);
        $supplier->first_name  = $request->first_name;
        $supplier->last_name   = $request->last_name;
        if($request->has('phone')){
        //$num = preg_replace('/[^0-9.]/', '', $request->phone);
        $num = preg_replace('/[0-9]{3}\.?([0-9]{3})\.?([0-9]{4})/', '', $request->phone);
        $supplier->mobile     = $num;    
        }
        $supplier->billing_address    = $request->billing_address;
        $supplier->billing_city       = $request->billing_city;
        $supplier->billing_provience  = $request->billing_provience;
        $supplier->billing_country    = $request->billing_country;
        $supplier->billing_pincode    = $request->billing_pincode;
        if(isset($request->update_shipping)){
            $supplier->is_shipping_address_different   = 1;
            $supplier->shipping_address   = $request->shipping_address;
            $supplier->shipping_city      = $request->shipping_city;
            $supplier->shipping_provience = $request->shipping_provience;
            $supplier->shipping_country   = $request->shipping_country;
            $supplier->shipping_pincode   = $request->shipping_pincode; 
        }else{
            $supplier->is_shipping_address_different   = 0;
            $supplier->shipping_address   = $request->billing_address;
            $supplier->shipping_city      = $request->billing_city;
            $supplier->shipping_provience = $request->billing_provience;
            $supplier->shipping_country   = $request->billing_country;
            $supplier->shipping_pincode   = $request->billing_pincode; 
        }
        /*if (isset($supplier->confirm_password)) {
            $supplier->password   = Hash::make($request->password);
        }*/
        
        $supplier->save();
        return redirect()->back()->with('message', 'Profile has been updated successfully');
    
    }
    
    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        User::find($id)->delete();
        return redirect()->route('users.index')
                        ->with('success','User deleted successfully');
    }
}